@@ -757,16 +757,24 @@ mod tests {
         let interval2 = IntervalDT::parse("-0 00:00:00.000011", "DD HH24:MI:SS.FF").unwrap();
         assert_eq!(interval, interval2);
 
+        let interval = IntervalDT::try_from_usecs(-12).unwrap();
+        let interval2 = IntervalDT::parse("-0 00:00:00.000011567", "DD HH24:MI:SS.FF").unwrap();
+        assert_eq!(interval, interval2);
+
         let interval = IntervalDT::try_from_dhms(12, 4, 5, 6, 0).unwrap().negate();
         let interval2 = IntervalDT::parse("-12 4:5:6", "DD HH24:MI:SS").unwrap();
         assert_eq!(interval, interval2);
 
         // Invalid
-        assert!(IntervalDT::parse("100000000 02:00:00:00.0", "DD HH24:MI:SS.FF").is_err());
+        assert!(IntervalDT::parse("100000000 02:00:00.0", "DD HH24:MI:SS.FF").is_err());
         assert!(IntervalDT::parse("0 24:00:00:00.0", "DD HH24:MI:SS.FF").is_err());
-        assert!(IntervalDT::parse("100000001 00:00:00:00.0", "DD HH24:MI:SS.FF").is_err());
-        assert!(IntervalDT::parse("-100000001 00:00:00:00.0", "DD HH24:MI:SS.FF").is_err());
-        assert!(IntervalDT::parse("-100000000 02:00:00:00.0", "DD HH24:MI:SS.FF").is_err());
+        assert!(IntervalDT::parse("100000001 00:00:00.0", "DD HH24:MI:SS.FF").is_err());
+        assert!(IntervalDT::parse("-100000001 00:00:00.0", "DD HH24:MI:SS.FF").is_err());
+        assert!(IntervalDT::parse("-100000000 02:00:00.0", "DD HH24:MI:SS.FF").is_err());
+
+        assert!(IntervalDT::parse("-100000 02:00", "DD HH24:MI:SS.FF").is_err());
+        assert!(IntervalDT::parse("-100000 02", "DD HH24:MI:SS.FF").is_err());
+        assert!(IntervalDT::parse("-100000 ", "DD HH24:MI:SS.FF").is_err());
 
         assert!(IntervalDT::parse("1919", "yyyy").is_err());
         assert!(IntervalDT::parse("19", "mm").is_err());
